@@ -268,9 +268,9 @@ class IRFF(Calculator):
          fpi_        = self.f_nn('fpi',[self.eterm2],layer=self.bo_layer[1])
          fpp_        = self.f_nn('fpp',[self.eterm3],layer=self.bo_layer[1])
          
-         self.bop_si = fsi_*self.eterm1
-         self.bop_pi = fpi_*self.eterm2
-         self.bop_pp = fpp_*self.eterm3
+         self.bop_si = fsi_ #*self.frc #*self.eterm1
+         self.bop_pi = fpi_ #*self.frc #*self.eterm2
+         self.bop_pp = fpp_ #*self.frc #*self.eterm3
       else:
          self.bop_si = taper(self.eterm1,rmin=self.botol,rmax=2.0*self.botol)*(self.eterm1-self.botol) # consist with GULP
          self.bop_pi = taper(self.eterm2,rmin=self.botol,rmax=2.0*self.botol)*self.eterm2
