@@ -77,9 +77,9 @@ def freq(atoms=None):
 
 
 def md(atoms=None,gen='poscar.gen',step=100,model='mpnn',initT=300,timeStep=0.1,
-       vdwnn=False):
+       vdwnn=False,print_interval=1):
     irmd = IRMD(time_step=timeStep,totstep=step,atoms=atoms,gen=gen,Tmax=10000,
-                ro=0.8,rmin=0.5,initT=initT,vdwnn=vdwnn)
+                ro=0.8,rmin=0.5,initT=initT,vdwnn=vdwnn,print_interval=print_interval)
     irmd.run()
 
     irmd.close()
