@@ -114,7 +114,7 @@ def DIV_IF(y,x):
 class ReaxFF(object):
   def __init__(self,libfile='ffield',direcs={},
                dft='ase',atoms=None,
-               cons=['val','vale','lp3','hbtol'],
+               cons=['val','vale','lp3'], #,'hbtol'
                opt=None,optword='nocoul',
                VariablesToOpt=None,
                nanv={'boc1':-2.0},
@@ -488,6 +488,7 @@ class ReaxFF(object):
   def get_loss(self):
       self.Loss = 0.0
       for mol in self.mols:
+          mol_ = mol.split('-')[0]
           if self.losFunc   == 'n2':
              self.loss[mol] = tf.nn.l2_loss(self.E[mol]-self.dft_energy[mol],
                                  name='loss_%s' %mol)
@@ -501,8 +502,8 @@ class ReaxFF(object):
           sum_edft = tf.reduce_sum(input_tensor=tf.abs(self.dft_energy[mol]-self.zpe[mol])) # self.max_e[mol]
           self.accur[mol] = 1.0 - tf.reduce_sum(input_tensor=tf.abs(self.E[mol]-self.dft_energy[mol]))/(sum_edft+0.00000001)
           
-          if mol in self.weight:
-             self.Loss     += self.loss[mol]*self.weight[mol]
+          if mol_ in self.weight:
+             self.Loss     += self.loss[mol]*self.weight[mol_]
           else:
              self.Loss     += self.loss[mol]
           
@@ -1273,7 +1274,7 @@ class ReaxFF(object):
           elif key=='hbtol':
              self.p[k] = tf.clip_by_value(self.v[k],0.0001,0.1)
           elif key=='cutoff':
-             self.p[k] = tf.clip_by_value(self.v[k],0.01,2.0)
+             self.p[k] = tf.clip_by_value(self.v[k],0.01,2.5)
           elif key=='ovun5':
              self.p[k] = tf.clip_by_value(self.v[k],0.0,999.0*self.unit)
           elif key=='ovun1':
@@ -1314,9 +1315,15 @@ class ReaxFF(object):
           elif key in ['V1','V2','V3']:
              self.p[k] = tf.clip_by_value(self.v[k],-99.9900*self.unit,990.0*self.unit)
           elif key in ['bo1','bo3','bo5']:
-             self.p[k] = tf.clip_by_value(self.v[k],-50.0,-0.0001)
+             if self.nn:
+                self.p[k] = tf.clip_by_value(self.v[k],-0.9,-0.1)
+             else:
+                self.p[k] = tf.clip_by_value(self.v[k],-50.0,-0.0001)
           elif key in ['bo2','bo4','bo6']:
-             self.p[k] = tf.clip_by_value(self.v[k],0.0,50.0)
+             if self.nn:
+                self.p[k] = tf.clip_by_value(self.v[k],2.0,8.0)
+             else:
+                self.p[k] = tf.clip_by_value(self.v[k],0.0,50.0)
           elif key == 'boc1':
              self.p[k] = tf.clip_by_value(self.v[k],0.001,50.0)
           elif key == 'boc2':
@@ -1348,7 +1355,7 @@ class ReaxFF(object):
           elif key == 'rohb':
              self.p[k] = tf.clip_by_value(self.v[k],1.5,3.6)
           elif key == 'rvdw':
-             rvdw_ = 1.35*self.p_['rosi_'+vn[1]]
+             rvdw_ = 1.3*self.p_['rosi_'+vn[1]]
              self.p[k] = tf.clip_by_value(self.v[k],rvdw_,2.0*self.p_['rosi_'+vn[1]])
           elif key=='val':
              sp = vn[1]
